pub struct CheckpointData {
pub file: String,
pub line: usize,
}Expand description
Persisted checkpoint data recording the current file and line position.
Fields
file: Stringline: usizeImplementations
Sourceimpl CheckpointData
impl CheckpointData
Sourcepub async fn load(path: &Utf8PathBuf) -> Result<Option<Self>>
pub async fn load(path: &Utf8PathBuf) -> Result<Option<Self>>
Load a checkpoint from the given path.
Returns Ok(None) if the file does not exist.
Sourcepub fn save_atomic(
checkpoint_path: &Utf8PathBuf,
file: &Utf8PathBuf,
line: usize,
) -> Result<()>
pub fn save_atomic( checkpoint_path: &Utf8PathBuf, file: &Utf8PathBuf, line: usize, ) -> Result<()>
Atomically write a checkpoint file by writing to a temporary file in the same directory and then renaming it into place.